@@ -2,6 +2,7 @@ import sqlalchemy as alc
 import logging
 import pandas as pd
 import datetime as dt
+import os
 
 import operator
 
@@ -15,7 +16,7 @@ class Session:
                 host ---- host ip to connect to
 
             kwargs:
-                db ---- database to connect to (defaults to test)
+                db ---- database to connect to (defaults to Test)
         """
         self.engine = alc.create_engine("mysql+pymysql://{}:{}@{}/{}".format(user, password, host, db), echo=True)
 
@@ -127,11 +128,31 @@ class Session:
             print(e)
             quit() 
 
+    def insert_directory(self, directory, table, overwrite):
+        """Insert all csv files from directory into table.
+
+        Args:
+            directory (string): directory to insert
+            table (string): table to insert into
+            overwrite (bool): If true, overwrite table in sql database. If false, append.
+        """
+
+        # iterate over filenames and insert CSVs as found
+        for filename in os.listdir(directory):
+            if filename.endswith('.csv'):
+                path = os.path.join(directory, filename)
+                self.insert_from_CSV(path, table, overwrite)
+
+                # reassign overwrite so that insert_from_CSV doesn't overwrite on each insert
+                overwrite = False
+
     def create_table(self, table, columns, types):
         """ create table from given dataframe
 
             args:
-                dataframe ---- dataframe to base table off of
+                table ---- name of table to be created
+                columns ---- list of column names
+                types ---- list of types for the columns
         """
         
         # create table with dataframe data
@@ -147,7 +168,7 @@ class Session:
         """ Select elements with corresponding row and column values
 
             args:
-                tables ---- list of tables to select elements from
+                query_tables ---- list of tables to select elements from
 
             kwargs:
                 conditions ---- dictionary of column names and conditions.
